@@ -26,7 +26,8 @@ BBoptim <- function(par, fn, gr=NULL, method=c(2,3,1), project=NULL,
 	            lower=lower, upper=upper, 
 		    control=list(M=as.numeric(cpars[2]), maxit=maxit, 
 		       maximize=maximize, trace=trace, triter=triter, 
-		       maxfeval=maxfeval, eps=eps), ...),    silent=TRUE)
+		       maxfeval=maxfeval, eps=eps),
+		    quiet=quiet, ...),    silent=TRUE)
 
       if (!inherits(temp, "try-error")) {
    	 feval <- feval + temp$feval
